@@ -9,7 +9,7 @@ from vstools import core, vs
 from ..abstract import Antialiaser, DoubleRater, SingleRater, SuperSampler, _Antialiaser, _FullInterpolate
 
 __all__ = [
-    'Nnedi3', 'Nnedi3SS', 'Nnedi3SR', 'Nnedi3DR'
+    'NNEDI3', 'Nnedi3', 'Nnedi3SS', 'Nnedi3SR', 'Nnedi3DR'
 ]
 
 
