@@ -9,7 +9,7 @@ from ..abstract import Antialiaser, DoubleRater, SingleRater, SuperSampler, _Ant
 from .nnedi3 import NNEDI3
 
 __all__ = [
-    'Znedi3', 'Znedi3SS', 'Znedi3SR', 'Znedi3DR'
+    'ZNEDI3', 'Znedi3', 'Znedi3SS', 'Znedi3SR', 'Znedi3DR'
 ]
 
 
